document.addEventListener('DOMContentLoaded', function () {
  const modal = document.getElementById('massAddModal');
  const productList = document.getElementById('mass-add-list');

  modal.addEventListener('show.bs.modal', async function () {
    let addedProducts = new Set();
    document.querySelectorAll('#items li').forEach(li => {
      if (li.dataset.name) {
        addedProducts.add(li.dataset.name.toLowerCase());
      }
    });

    productList.innerHTML = '<li class="list-group-item bg-dark text-light">Ładowanie...</li>';
    try {
      const res = await fetch('/all_products');
      const data = await res.json();
      const allproducts = data.allproducts;
      productList.innerHTML = '';
      allproducts.forEach(name => {
        const li = document.createElement('li');
        li.className = 'list-group-item d-flex justify-content-between align-items-center bg-dark text-light';

        if (addedProducts.has(name.toLowerCase())) {
          // Produkt już dodany — oznacz jako nieaktywny
          const nameSpan = document.createElement('span');
          nameSpan.textContent = name;
          li.appendChild(nameSpan);

          li.classList.add('opacity-50');
          const badge = document.createElement('span');
          badge.className = 'badge bg-success ms-auto';
          badge.textContent = 'Dodano';
          li.appendChild(badge);
        } else {
          // Nazwa produktu
          const nameSpan = document.createElement('span');
          nameSpan.textContent = name;
          nameSpan.style.flex = '1 1 auto';
          li.appendChild(nameSpan);

          // Kontener na minus, pole i plus
          const qtyWrapper = document.createElement('div');
          qtyWrapper.className = 'd-flex align-items-center ms-2 quantity-controls';

          // Minus
          const minusBtn = document.createElement('button');
          minusBtn.type = 'button';
          minusBtn.className = 'btn btn-outline-light btn-sm px-2';
          minusBtn.textContent = '−';
          minusBtn.onclick = () => {
            qty.value = Math.max(1, parseInt(qty.value) - 1);
          };

          // Pole ilości
          const qty = document.createElement('input');
          qty.type = 'number';
          qty.min = 1;
          qty.value = 1;
          qty.className = 'form-control text-center p-1';
          qty.classList.add('rounded');
          qty.style.width = '50px';
          qty.style.margin = '0 2px';
          qty.title = 'Ilość';

          // Plus
          const plusBtn = document.createElement('button');
          plusBtn.type = 'button';
          plusBtn.className = 'btn btn-outline-light btn-sm px-2';
          plusBtn.textContent = '+';
          plusBtn.onclick = () => {
            qty.value = parseInt(qty.value) + 1;
          };

          qtyWrapper.appendChild(minusBtn);
          qtyWrapper.appendChild(qty);
          qtyWrapper.appendChild(plusBtn);

          // Przycisk dodania
          const btn = document.createElement('button');
          btn.className = 'btn btn-sm btn-primary ms-4';
          btn.textContent = '+';
          btn.onclick = () => {
            const quantity = parseInt(qty.value) || 1;
            socket.emit('add_item', { list_id: LIST_ID, name: name, quantity: quantity });
          };

          li.appendChild(qtyWrapper);
          li.appendChild(btn);
        }
        productList.appendChild(li);
      });

    } catch (err) {
      productList.innerHTML = '<li class="list-group-item text-danger bg-dark">Błąd ładowania danych</li>';
    }
  });

  socket.on('item_added', data => {
    document.querySelectorAll('#mass-add-list li').forEach(li => {
      const itemName = li.firstChild.textContent.trim();

      if (itemName === data.name && !li.classList.contains('opacity-50')) {
        // Usuń wszystkie dzieci
        while (li.firstChild) {
          li.removeChild(li.firstChild);
        }

        // Ustaw nazwę
        li.textContent = data.name;

        // Dodaj klasę wyszarzenia
        li.classList.add('opacity-50');

        // Dodaj badge
        const badge = document.createElement('span');
        badge.className = 'badge bg-success ms-auto';
        badge.textContent = 'Dodano';
        li.appendChild(badge);

        // Zablokuj kliknięcia
        li.onclick = null;
      }
    });
  });
});
